---
name: 🐜 Bug report
about: Create a report to help us improve 🔧
labels: bug
---

<!-- Place a general description or your issue here. -->

## Steps to Reproduce the Problem
<!-- Tell us how to reproduce your issue -->

  1.
  1.
  1.

## Example Reclass inventory
<!--
If at all feasible, please provide a minimal example inventory that
demonstrates the buggy behavior. By doing so, you're making it much easier for
us to fix the reported bug.

You can share an example inventory as follows:

1. Setup the example inventory structure (including `reclass-config.yml` if
   necessary) in a temporary directory
2. Verify that the example inventory demonstrates the buggy behavior
3. Run `tar cj * | base64 -w 0` in the temporary directory
   On macOS, you'll need to leave out `-w 0`.
4. Copy the resulting base64 string into a code block in this section
5. If you've changed the `tar` command, please provide your version
-->

## Actual Behavior
<!-- What did happen as a result of the above? -->

## Expected Behavior
<!-- What is your expectation of the result? -->
